Bela_InitSettings_alloc

Function Bela_InitSettings_alloc 

pub unsafe extern "C" fn Bela_InitSettings_alloc() -> *mut BelaInitSettings
\brief Allocate the data structure containing settings for Bela.

This function should be used to allocate the structure that holds initialisation data for Bela in order to preserve binary compatibility across versions of the library.