pub unsafe extern "C" fn Bela_createAuxiliaryTask(
callback: Option<unsafe extern "C" fn(arg1: *mut c_void)>,
priority: c_int,
name: *const c_char,
arg: *mut c_void,
) -> AuxiliaryTaskExpand description
\brief Create a new auxiliary task.
This function creates a new auxiliary task which, when scheduled, runs the function specified
in the first argument. Note that the task does not run until scheduleAuxiliaryTask() is called.
Auxiliary tasks should be created in setup() and never in render() itself.
The second argument specifies the real-time priority. Valid values are between 0 and 99, and usually should be lower than \ref BELA_AUDIO_PRIORITY. Tasks with higher priority always preempt tasks with lower priority.
\param callback Function which will be called each time the auxiliary task is scheduled, unless it is already running. \param priority Xenomai priority level at which the task should run. \param name Name for this task, which should be unique system-wide (no other running program should use this name). \param arg The argument passed to the callback function.