pub unsafe extern "C" fn Bela_initAudio(
settings: *mut BelaInitSettings,
userData: *mut c_void,
) -> c_intExpand description
\brief Initialise audio and sensor rendering environment.
This function prepares audio rendering in Bela. It should be called from main() sometime after command line option parsing has finished. It will initialise the rendering system, which in the process will result in a call to the user-defined setup() function.
\param settings Data structure holding system settings, including numbers of channels, frame sizes, volume levels and other information. \param userData An opaque pointer to a user-defined data structure which will be passed to setup(), render() and cleanup(). You can use this to pass custom information to the rendering functions, as an alternative to using global variables.
\return 0 on success, or nonzero if an error occurred.