Bela_setAdcLevel

Function Bela_setAdcLevel 

pub unsafe extern "C" fn Bela_setAdcLevel(
    channel: c_int,
    decibels: f32,
) -> c_int
\brief Set the level of the audio ADC.

This function sets the level of the audio input. It does not affect the level of the (non-audio) analog inputs.

\b Important: do not call this function from within render(), as it does not make any guarantees on real-time performance.

\param channel The channel to set. Use a negative value to set all channels. \param decibels Level of the ADC input. Valid levels range from -12 (lowest) to 0 (highest) in steps of 1.5dB. Levels between increments of 1.5 will be rounded down.

\return 0 on success, or nonzero if an error occurred.