pub type BelaDigitalDirection = c_uint;Expand description
\defgroup iofunctions I/O functions and constants
These functions and macros are used for audio, analog and digital I/O. All the I/O functions require the BelaContext data structure from render() to be passed in. This means that these functions are, by design, \b only usable from within the rendering thread.
The naming conventions are loosely derived from the Arduino environment, and the syntax is similar. Unlike Arduino, the I/O functions require the frame number at which the read or write should take place, since all I/O happens synchronously with the audio clock.
@{