pub unsafe extern "C" fn Bela_runInSameThread() -> c_intExpand description
\brief Begin processing audio and sensor data in the same thread as the caller.
This function will start the Bela audio/sensor system. After this function is called, the system will make periodic calls to render() until Bela_stopAudio() is called.
\return 0 on success, or nonzero if an error occurred.