pub unsafe extern "C" fn Bela_setAudioInputGain(
channel: c_int,
decibels: f32,
) -> c_intExpand description
\brief Set the gain of the audio input preamplifier.
This function sets the level of the Programmable Gain Amplifier(PGA), which amplifies the signal before the ADC.
\b Important: do not call this function from within render(), as it does not make any guarantees on real-time performance.
\param channel The channel to set. Use a negative value to set all channels. \param decibels Level of the PGA Valid levels range from 0 (lowest) to 59.5 (highest) in steps of 0.5dB. Levels between increments of 0.5 will be rounded. channel 1 is right
\return 0 on success, or nonzero if an error occurred.