pub unsafe extern "C" fn Bela_setLineOutLevel(
channel: c_int,
decibel: f32,
) -> c_intExpand description
\brief Set the level of the audio line out.
\b Important: do not call this function from within render(), as it does not make any guarantees on real-time performance.
\param channel The channel to set. Use a negative value to set all channels. \param decibels Level of the line output. Valid values will depend on the codec in use.
\return 0 on success, or nonzero if an error occurred.